<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>MPRISFactory</name>
    <message>
        <location filename="../mprisfactory.cpp" line="29"/>
        <source>MPRIS Plugin</source>
        <translation>Модуль MPRIS</translation>
    </message>
    <message>
        <location filename="../mprisfactory.cpp" line="49"/>
        <source>About MPRIS Plugin</source>
        <translation>О модуле MPRIS</translation>
    </message>
    <message>
        <location filename="../mprisfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../mprisfactory.cpp" line="50"/>
        <source>Qmmp MPRIS Plugin</source>
        <translation>Модуль MPRIS для Qmmp</translation>
    </message>
</context>
</TS>
